/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.collectiverun.bean;


/**
 * 一括制御で使用するキューの定数クラスです。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class QueueConstant {
    /** 一括制御実行用キュー */
    public static final String QUEUE_NAME_EXECUTE = "queue/clustercontrolCollectiveRunExecute";
    /** 一括制御実行結果用キュー */
    public static final String QUEUE_NAME_STATUS = "queue/clustercontrolCollectiveRunStatus";
}
